@@ -17,8 +17,8 @@ test_that("justification() function works as expected.", {
   
   expect_equal(length(lst), 2)
   
-  
-  expect_error(justification(df1) <- list(mpd = "right"))
+  # No error now
+  justification(df1) <- list(mpd = "right")
   
   
   justification(df1)
